==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaFdcqxm.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;
import cn.gtmap.realestate.supervise.core.reflect.qxdm;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 房地产权（项目内多幢房屋）项目属性
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_fdcqxm"
)
public class BaFdcqxm implements Serializable {

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    private String xmmc;

    @XmlAttribute
    private String zh;

    @XmlAttribute
    @Nullable
    private String zcs;

    @XmlAttribute
    @Nullable
    private String ghyt;

    @XmlAttribute
    @Nullable
    private String fwjg;

    @XmlAttribute
    @Nullable
    private String jzmj;

    @XmlAttribute
    @Nullable
    private String jgsj;

    @XmlAttribute
    @Nullable
    private int zts;

    @XmlAttribute
    @Id
    @id
    private String id;

    @Nullable
    private Date sjgxsj;

    @XmlAttribute
    @qxdm
    private String qxdm;

    @bwmc
    private String bwmc;

    @ywh
    private String ywh;

    @XmlAttribute
    @ssywh
    private String ssywh;

    @XmlAttribute
    private String ytmc;

    @XmlAttribute
    private String pzyt;

    @XmlAttribute
    private String sjyt;

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getYtmc() {
        return ytmc;
    }

    public void setYtmc(String ytmc) {
        this.ytmc = ytmc;
    }

    public String getPzyt() {
        return pzyt;
    }

    public void setPzyt(String pzyt) {
        this.pzyt = pzyt;
    }

    public String getSjyt() {
        return sjyt;
    }

    public void setSjyt(String sjyt) {
        this.sjyt = sjyt;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public String getZh() {
        return zh;
    }

    public String getZcs() {
        return zcs;
    }

    public String getGhyt() {
        return ghyt;
    }

    public String getFwjg() {
        return fwjg;
    }

    public String getJzmj() {
        return jzmj;
    }

    public String getJgsj() {
        return jgsj;
    }

    public int getZts() {
        return zts;
    }


    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public void setZh(String zh) {
        this.zh = zh;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public void setJzmj(String jzmj) {
        this.jzmj = jzmj;
    }

    public void setJgsj(String jgsj) {
        this.jgsj = jgsj;
    }

    public void setZts(int zts) {
        this.zts = zts;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }
}

==> realestate-supervise-common-1.1.0-20251204.013828-71-sources.jar: cn/gtmap/realestate/supervise/entity/BaFdcqxm.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;
import cn.gtmap.realestate.supervise.core.reflect.qxdm;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 房地产权（项目内多幢房屋）项目属性
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_fdcqxm"
)
public class BaFdcqxm implements Serializable {

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    private String xmmc;

    @XmlAttribute
    private String zh;

    @XmlAttribute
    @Nullable
    private String zcs;

    @XmlAttribute
    @Nullable
    private String ghyt;

    @XmlAttribute
    @Nullable
    private String fwjg;

    @XmlAttribute
    @Nullable
    private String jzmj;

    @XmlAttribute
    @Nullable
    private String jgsj;

    @XmlAttribute
    @Nullable
    private int zts;

    @XmlAttribute
    @Id
    @id
    private String id;

    @Nullable
    private Date sjgxsj;

    @XmlAttribute
    @qxdm
    private String qxdm;

    @bwmc
    private String bwmc;

    @ywh
    private String ywh;

    @XmlAttribute
    @ssywh
    private String ssywh;

    @XmlAttribute
    private String ytmc;

    @XmlAttribute
    private String pzyt;

    @XmlAttribute
    private String sjyt;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段开始===============

    /** 用地用海分类代码 */
    @XmlAttribute
    private String ydyhfldm;

    /** 产权来源 */
    @XmlAttribute
    private String cqly;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段结束===============

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getYtmc() {
        return ytmc;
    }

    public void setYtmc(String ytmc) {
        this.ytmc = ytmc;
    }

    public String getPzyt() {
        return pzyt;
    }

    public void setPzyt(String pzyt) {
        this.pzyt = pzyt;
    }

    public String getSjyt() {
        return sjyt;
    }

    public void setSjyt(String sjyt) {
        this.sjyt = sjyt;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public String getZh() {
        return zh;
    }

    public String getZcs() {
        return zcs;
    }

    public String getGhyt() {
        return ghyt;
    }

    public String getFwjg() {
        return fwjg;
    }

    public String getJzmj() {
        return jzmj;
    }

    public String getJgsj() {
        return jgsj;
    }

    public int getZts() {
        return zts;
    }


    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public void setZh(String zh) {
        this.zh = zh;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public void setJzmj(String jzmj) {
        this.jzmj = jzmj;
    }

    public void setJgsj(String jgsj) {
        this.jgsj = jgsj;
    }

    public void setZts(int zts) {
        this.zts = zts;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getYdyhfldm() {
        return ydyhfldm;
    }

    public void setYdyhfldm(String ydyhfldm) {
        this.ydyhfldm = ydyhfldm;
    }

    public String getCqly() {
        return cqly;
    }

    public void setCqly(String cqly) {
        this.cqly = cqly;
    }
}
